pub struct DropdownAccept<T: 'static> {
pub value: T,
}Expand description
Event fired when an item is accepted/selected from the dropdown. Contains the selected value.
Note: Prefer using Dropdown::on_accept instead of listening for this event directly,
as it provides properly typed access to the selected value.
If you instead manually specify the incorrect type, a downcast will fail and your handler will not run.
Fields
value: TThe accepted value
Implementations
Sourceimpl<T: Clone + 'static> DropdownAccept<T>
impl<T: Clone + 'static> DropdownAccept<T>
Sourcepub fn listener() -> DropdownAcceptListener<T>
pub fn listener() -> DropdownAcceptListener<T>
Get the event listener for this custom event